@@ -34,6 +34,6 @@ class Watcher:
                 except ProcessLookupError:
                     # Process already finished.
                     pass
-            print("\n\n")
+            print("\n\n\n")
             await self._create_process()
             asyncio.create_task(self._print_process(self._process))
