@@ -1,23 +1,21 @@
-import asyncio
 import argparse
+import asyncio
 
 from .change_detector import ChangeDetector
 from .watcher import Watcher
 
 
 async def cli():
-    example = '\n'.join([
-        'Examples:',
-        '  wch -d src -d tests -- pytest',
-        '  wch -i docs -- black .'
-    ])
+    example = "\n".join(
+        ["Examples:", "  wch -d src -d tests -- pytest", "  wch -i docs -- black ."]
+    )
 
     parser = argparse.ArgumentParser(
         prog="wch",
         usage="%(prog)s [options] -- <command>",
         description="Runs the provided command on detected file changes.",
         epilog=example,
-        formatter_class=argparse.RawTextHelpFormatter
+        formatter_class=argparse.RawTextHelpFormatter,
     )
     parser.add_argument(
         "-d",
